@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -47,6 +47,7 @@ import javax.management.remote.JMXServiceURL;
 import com.openexchange.admin.console.AdminParser.NeededQuadState;
 import com.openexchange.admin.rmi.exceptions.InvalidDataException;
 import com.openexchange.admin.rmi.exceptions.MissingOptionException;
+import com.openexchange.java.Strings;
 
 /**
  * {@link AbstractJMXTools} can be extended to write a command line tool that is a JMX client.
@@ -246,7 +247,7 @@ public abstract class AbstractJMXTools extends BasicCommandlineOptions {
     }
 
     protected static Object doOperation(MBeanServerConnection mbc, String fullqualifiedoperationname) throws MalformedObjectNameException, NullPointerException, IOException, InvalidDataException, InstanceNotFoundException, MBeanException, ReflectionException {
-        String[] split = fullqualifiedoperationname.split("!");
+        String[] split = Strings.splitBy(fullqualifiedoperationname, '!', false);
         if (2 == split.length) {
             ObjectName objectName = new ObjectName(split[0]);
             Object result = mbc.invoke(objectName, split[1], null, null);
