@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -275,9 +275,29 @@ public class AdminParser extends CLIParser {
         return retval;
     }
 
+    /**
+     * @param longForm
+     * @param longFormParameterDescription
+     * @param description
+     * @param needed
+     * @param hasarg
+     * @return
+     */
+    public final CLIOption addOption(final String longForm, final String longFormParameterDescription, final String description, final NeededQuadState needed, final boolean hasarg) {
+        if (hasarg) {
+            final CLIOption retval = this.addStringOption(longForm);
+            this.optinfolist.add(new OptionInfo(needed, retval, longForm, longFormParameterDescription, description));
+            return retval;
+        }
+
+        final CLIOption retval = this.addBooleanOption(longForm);
+        this.optinfolist.add(new OptionInfo(NeededQuadState.notneeded, retval, longForm, description));
+        return retval;
+    }
+
     /**
      * Adds an option at the given position
-     * 
+     *
      * @param pos The position to insert the option
      * @param longForm The long form
      * @param longFormParameterDescription The long form description
@@ -442,8 +462,7 @@ public class AdminParser extends CLIParser {
             for (final OptionInfo optInfo : this.optinfolist) {
                 if (optInfo.needed == NeededQuadState.needed) {
                     if (null == getOptionValue(optInfo.option)) {
-                        sb.append(optInfo.longForm);
-                        sb.append(",");
+                        sb.append(optInfo.longForm).append(',');
                     }
                 }
             }
