@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -139,6 +139,11 @@ public abstract class BasicCommandlineOptions {
     protected static final String OPT_NAME_EXCLUDEUSERS_LONG = "excludeusers";
     protected static final String OPT_NAME_EXCLUDEUSERS_DESCRIPTION = "Exclude users, only show guests";
 
+    protected static final String OPT_NAME_LENTH_LONG = "length";
+    protected static final String OPT_NAME_LENGTH_DESCRIPTION = "Limit result size";
+    protected static final String OPT_NAME_OFFSET_LONG = "offset";
+    protected static final String OPT_NAME_OFFSET_DESCRIPTION = "Set offset for limited result size";
+
     private static final String[] ENV_OPTIONS = new String[] { "RMI_HOSTNAME", "COMMANDLINE_TIMEZONE", "COMMANDLINE_DATEFORMAT", "ADMIN_PASSWORD", "NEW_USER_PASSWORD" };
 
     protected static String RMI_HOSTNAME = "rmi://localhost:1099/";
@@ -158,6 +163,9 @@ public abstract class BasicCommandlineOptions {
     protected CLIOption includeGuestsOption = null;
     protected CLIOption excludeUsersOption = null;
 
+    protected CLIOption lengthOption = null;
+    protected CLIOption offsetOption = null;
+
     // Used for right error output
     protected Integer ctxid = null;
 
@@ -368,6 +376,10 @@ public abstract class BasicCommandlineOptions {
         return admp.addOption(longopt, longopt, description, required, hasarg);
     }
 
+    protected final CLIOption setLongOpt(AdminParser admp, String longopt, String description, boolean hasarg, NeededQuadState required) {
+        return admp.addOption(longopt, longopt, description, required, hasarg);
+    }
+
     protected final CLIOption setLongOpt(final AdminParser admp, final String longopt, final String description, final boolean hasarg, final boolean required, final boolean extended) {
         return admp.addOption(longopt, longopt, description, required, hasarg, extended);
     }
@@ -458,6 +470,24 @@ public abstract class BasicCommandlineOptions {
 
     // ------------------------------------------------------------------------------------- //
 
+    protected void setLengthOption(final AdminParser admp) {
+        setLengthOption(admp, false);
+    }
+
+    protected void setOffsetOption(final AdminParser admp) {
+        setOffsetOption(admp, false);
+    }
+
+    protected void setLengthOption(final AdminParser admp, boolean required) {
+        this.lengthOption = setLongOpt(admp, OPT_NAME_LENTH_LONG, OPT_NAME_LENGTH_DESCRIPTION, true, required);
+    }
+
+    protected void setOffsetOption(final AdminParser admp, boolean required) {
+        this.offsetOption = setLongOpt(admp, OPT_NAME_OFFSET_LONG, OPT_NAME_OFFSET_DESCRIPTION, true, required);
+    }
+
+    // ------------------------------------------------------------------------------------- //
+
     protected final void setSearchPatternOption(final AdminParser admp) {
         this.searchOption = setShortLongOpt(admp, OPT_NAME_SEARCHPATTERN, OPT_NAME_SEARCHPATTERN_LONG, "The search pattern which is used for listing", true, NeededQuadState.notneeded);
     }
