@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -38,6 +38,7 @@ import com.openexchange.admin.rmi.exceptions.NoSuchGroupException;
 import com.openexchange.admin.rmi.exceptions.NoSuchResourceException;
 import com.openexchange.admin.rmi.exceptions.NoSuchUserException;
 import com.openexchange.admin.rmi.exceptions.StorageException;
+import com.openexchange.java.Strings;
 
 /**
  * This abstract class declares an abstract method to get the object name with which the command line tool
@@ -103,7 +104,7 @@ public abstract class ObjectNamingAbstraction extends BasicCommandlineOptions {
 
     private void createMessage(String message, PrintStream ps, AdminParser parser, boolean followingtext) {
         if (null != parser && parser.checkNoNewLine()) {
-            String output = null == message || 0 == message.length() ? "" : message.replaceAll("\r?\n", "");
+            String output = null == message || 0 == message.length() ? "" : Strings.dropCRLFFrom(message);
             if (followingtext) {
                 ps.print(output);
             } else {
