@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -25,6 +25,7 @@ import java.rmi.RemoteException;
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Options;
 import com.openexchange.admin.rmi.OXContextGroupInterface;
+import com.openexchange.auth.Credentials;
 import com.openexchange.auth.rmi.RemoteAuthenticator;
 import com.openexchange.cli.AbstractRmiCLI;
 import com.openexchange.java.Strings;
@@ -62,8 +63,11 @@ public class DeleteContextGroup extends AbstractRmiCLI<Void> {
 
     @Override
     protected Void invoke(Options options, CommandLine cmd, String optRmiHostName) throws Exception {
+        String adminUser = cmd.getOptionValue('A');
+        String adminPassword = cmd.getOptionValue('P');
+
         OXContextGroupInterface oxContexGroup = getRmiStub(OXContextGroupInterface.RMI_NAME);
-        oxContexGroup.deleteContextGroup(cmd.getOptionValue('g'));
+        oxContexGroup.deleteContextGroup(cmd.getOptionValue('g'), new Credentials(adminUser, adminPassword));
         return null;
     }
 
