@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -30,6 +30,7 @@ import com.openexchange.admin.rmi.dataobjects.Credentials;
 import com.openexchange.admin.rmi.dataobjects.Group;
 import com.openexchange.admin.rmi.dataobjects.User;
 import com.openexchange.admin.rmi.exceptions.DuplicateExtensionException;
+import com.openexchange.java.Strings;
 
 public abstract class ChangeCore extends GroupAbstraction {
 
@@ -99,7 +100,7 @@ public abstract class ChangeCore extends GroupAbstraction {
     }
 
     private User[] getMembers(String tmpmembers) {
-        final String[] split = tmpmembers.split(",");
+        final String[] split = Strings.splitByComma(tmpmembers);
         final User[] memberList = new User[split.length];
         for (int i = 0; i < split.length; i++) {
             memberList[i] = new User(Integer.parseInt(split[i]));
