@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -30,6 +30,7 @@ import com.openexchange.admin.rmi.dataobjects.Context;
 import com.openexchange.admin.rmi.dataobjects.Credentials;
 import com.openexchange.admin.rmi.dataobjects.Group;
 import com.openexchange.admin.rmi.exceptions.DuplicateExtensionException;
+import com.openexchange.java.Strings;
 
 public abstract class CreateCore extends GroupAbstraction {
 
@@ -82,7 +83,7 @@ public abstract class CreateCore extends GroupAbstraction {
     }
 
     private Integer[] getMembers(final String tmpmembers) {
-        final String[] split = tmpmembers.split(",");
+        final String[] split = Strings.splitByComma(tmpmembers);
         final Integer[] memberList = new Integer[split.length];
         for (int i = 0; i < split.length; i++) {
             memberList[i] = I(Integer.parseInt(split[i]));
