@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -53,9 +53,9 @@ public class ListUsersByAliasDomain extends ListCore {
     }
 
     @Override
-    protected User[] maincall(final AdminParser parser, final OXUserInterface oxusr, final Context ctx, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException, NoSuchUserException {
+    protected User[] maincall(final AdminParser parser, final OXUserInterface oxusr, final Context ctx, final Credentials auth, final Integer length, final Integer offset) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException, NoSuchUserException {
         String domain = (String) parser.getOptionValue(alias_domain_cli_option);
-        User[] ids = oxusr.listByAliasDomain(ctx, domain, auth);
+        User[] ids = oxusr.listByAliasDomain(ctx, domain, auth, length, offset);
         if (ids.length == 0) {
             return new User[0];
         }
@@ -65,6 +65,8 @@ public class ListUsersByAliasDomain extends ListCore {
     @Override
     protected void setFurtherOptions(final AdminParser parser) {
         alias_domain_cli_option = setShortLongOpt(parser, ALIAS_DOMAIN_SHORT, ALIAS_DOMAIN, "The domain of the user aliases.", true, NeededQuadState.needed);
+        setLengthOption(parser);
+        setOffsetOption(parser);
     }
 
     @Override
