@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -22,6 +22,7 @@
 package com.openexchange.admin.diff.file.handler.impl;
 
 import java.io.IOException;
+import java.io.Reader;
 import java.io.StringReader;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -97,7 +98,7 @@ public class PropertyHandler extends AbstractFileHandler {
             try {
                 String originalFileContent = origFile.getContent();
                 Properties originalProperty = new Properties();
-                originalProperty.load(new StringReader(originalFileContent));
+                loadPropertiesFrom(new StringReader(originalFileContent), originalProperty);
 
                 final String fileName = origFile.getName();
                 List<ConfigurationFile> result = new ConfigurationFileSearch().search(lInstalledFiles, fileName);
@@ -108,7 +109,7 @@ public class PropertyHandler extends AbstractFileHandler {
                 }
 
                 Properties installedProperty = new Properties();
-                installedProperty.load(new StringReader(result.get(0).getContent()));
+                loadPropertiesFrom(new StringReader(result.get(0).getContent()), installedProperty);
 
                 getDiffProperties(diffResult, fileName, originalProperty, installedProperty);
             } catch (IOException e) {
@@ -117,6 +118,16 @@ public class PropertyHandler extends AbstractFileHandler {
         }
     }
 
+    private void loadPropertiesFrom(Reader reader, Properties originalProperty) throws IOException {
+        if (reader != null) {
+            try {
+                originalProperty.load(reader);
+            } finally {
+                reader.close();
+            }
+        }
+    }
+
     /**
      * Diffs the given properties of one file and adds the diff to the given DiffResult.
      *
