@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -37,7 +37,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Optional;
 import java.util.Set;
-import java.util.concurrent.ExecutionException;
+import java.util.concurrent.RejectedExecutionException;
 import java.util.regex.Pattern;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
@@ -83,7 +83,6 @@ import com.openexchange.admin.storage.interfaces.OXUtilStorageInterface;
 import com.openexchange.admin.taskmanagement.TaskManager;
 import com.openexchange.admin.tools.AdminCache;
 import com.openexchange.admin.tools.filestore.FilestoreDataMover;
-import com.openexchange.admin.tools.filestore.PostProcessTask;
 import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheKey;
 import com.openexchange.caching.CacheService;
@@ -170,7 +169,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             if (com.openexchange.java.Strings.isEmpty(sModule)) {
                 throw new InvalidDataException("No valid module specified.");
             }
-            final String[] mods = sModule.split(" *, *");
+            final String[] mods = Strings.splitByComma(sModule);
             final Set<String> modules = new LinkedHashSet<>(mods.length);
             for (final String mod : mods) {
                 modules.add(mod);
@@ -503,7 +502,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                                 Map<String, Object> undoInfo = extended.undoableDelete(ctx, auth);
                                 if (undoInfo != null) {
                                     if (undeleteInfos == null) {
-                                        undeleteInfos = new LinkedHashMap<OXContextPluginInterfaceExtended, Map<String, Object>>(plugins.size());
+                                        undeleteInfos = new LinkedHashMap<>(plugins.size());
                                     }
                                     undeleteInfos.put(extended, undoInfo);
                                 }
@@ -1098,6 +1097,12 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         }
 
         try {
+        	try {
+                setIdOrGetIDFromNameAndIdObject(null, ctx);
+            } catch (NoSuchObjectException e) {
+                throw new NoSuchContextException(e);
+            }
+        	
             BasicAuthenticator.createNonPluginAwareAuthenticator().doAuthentication(auth);
 
             Context retval = null;
@@ -1111,78 +1116,70 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 log(LogLevel.ERROR, LOGGER, credentials, ctx.getIdAsString(), e, "");
                 throw new StorageException(e.getMessage());
             }
+            checkExistence(ctx);
+            if (!tool.existsStore(dst_filestore.getId().intValue())) {
+                throw new NoSuchFilestoreException();
+            } else if (!tool.isContextEnabled(ctx)) {
+                throw new OXContextException("Unable to disable Context " + ctx.getIdAsString());
+            }
+
+            retval = oxcox.getData(ctx);
+
+            // Check equality
+            int srcStore_id = retval.getFilestoreId().intValue();
+            ctx.setFilestoreId(Integer.valueOf(srcStore_id));
+            if (srcStore_id == dst_filestore.getId().intValue()) {
+                throw new OXContextException("The identifiers for the source and destination storage are equal: " + dst_filestore);
+            }
+
+            // Check storage name
+            String ctxdir = retval.getFilestore_name();
+            if (ctxdir == null) {
+                throw new OXContextException("Unable to get filestore directory " + ctx.getIdAsString());
+            }
+
+            OXUtilStorageInterface oxu = OXUtilStorageInterface.getInstance();
+            Filestore destFilestore = oxu.getFilestore(dst_filestore.getId().intValue(), false);
+
+            // Check capacity
+            if (!oxu.hasSpaceForAnotherContext(destFilestore)) {
+                throw new StorageException("Destination filestore does not have enough space for another context.");
+            }
+
+            // Load it to ensure validity
+            String baseUri = destFilestore.getUrl();
             try {
-                try {
-                    setIdOrGetIDFromNameAndIdObject(null, ctx);
-                } catch (NoSuchObjectException e) {
-                    throw new NoSuchContextException(e);
-                }
-                checkExistence(ctx);
-                if (!tool.existsStore(dst_filestore.getId().intValue())) {
-                    throw new NoSuchFilestoreException();
-                } else if (!tool.isContextEnabled(ctx)) {
-                    throw new OXContextException("Unable to disable Context " + ctx.getIdAsString());
-                }
+                URI uri = FileStorages.getFullyQualifyingUriForContext(ctx.getId().intValue(), new java.net.URI(baseUri));
+                FileStorages.getFileStorageService().getFileStorage(uri);
+            } catch (OXException e) {
+                throw StorageException.wrapForRMI(e);
+            } catch (URISyntaxException e) {
+                throw new StorageException("Invalid file storage URI: " + baseUri, e);
+            }
 
-                retval = oxcox.getData(ctx);
+            try {
+                // Initialize mover instance
+                FilestoreDataMover fsdm = FilestoreDataMover.newContextMover(oxu.getFilestore(srcStore_id, false), destFilestore, ctx);
 
-                // Check equality
-                int srcStore_id = retval.getFilestoreId().intValue();
-                ctx.setFilestoreId(Integer.valueOf(srcStore_id));
-                if (srcStore_id == dst_filestore.getId().intValue()) {
-                    throw new OXContextException("The identifiers for the source and destination storage are equal: " + dst_filestore);
-                }
+                // Enable context after processing
+                fsdm.addPostProcessTask(executionError -> {
+                    if (null == executionError) {
+                        oxcox.enable(ctx);
+                        invalidateContextCache(ctx, credentials);
+                    } else {
+                        log(LogLevel.WARNING, LOGGER, credentials, ctx.getIdAsString(), null, "An execution error occurred during \"movefilestore\" for context {}. Context will stay disabled.", ctx.getId(), executionError.getCause());
+                    }
+                });
 
-                // Check storage name
-                String ctxdir = retval.getFilestore_name();
-                if (ctxdir == null) {
-                    throw new OXContextException("Unable to get filestore directory " + ctx.getIdAsString());
-                }
-
-                OXUtilStorageInterface oxu = OXUtilStorageInterface.getInstance();
-                Filestore destFilestore = oxu.getFilestore(dst_filestore.getId().intValue(), false);
-
-                // Check capacity
-                if (!oxu.hasSpaceForAnotherContext(destFilestore)) {
-                    throw new StorageException("Destination filestore does not have enough space for another context.");
-                }
-
-                // Load it to ensure validity
-                String baseUri = destFilestore.getUrl();
-                try {
-                    URI uri = FileStorages.getFullyQualifyingUriForContext(ctx.getId().intValue(), new java.net.URI(baseUri));
-                    FileStorages.getFileStorageService().getFileStorage(uri);
-                } catch (OXException e) {
-                    throw StorageException.wrapForRMI(e);
-                } catch (URISyntaxException e) {
-                    throw new StorageException("Invalid file storage URI: " + baseUri, e);
-                }
-
-                try {
-                    // Initialize mover instance
-                    FilestoreDataMover fsdm = FilestoreDataMover.newContextMover(oxu.getFilestore(srcStore_id, false), destFilestore, ctx);
-
-                    // Enable context after processing
-                    fsdm.addPostProcessTask(new PostProcessTask() {
-
-                        @Override
-                        public void perform(ExecutionException executionError) throws StorageException {
-                            if (null == executionError) {
-                                oxcox.enable(ctx);
-                            } else {
-                                log(LogLevel.WARNING, LOGGER, credentials, ctx.getIdAsString(), null, "An execution error occurred during \"movefilestore\" for context {}. Context will stay disabled.", ctx.getId(), executionError.getCause());
-                            }
-                        }
-                    });
-
-                    // Schedule task
-                    oxcox.disable(ctx, reason);
-                    return TaskManager.getInstance().addJob(fsdm, "movefilestore", "move context " + ctx.getIdAsString() + " to filestore " + dst_filestore.getId(), ctx.getId().intValue());
-                } catch (StorageException e) {
-                    throw new StorageException(e.getMessage());
-                }
-            } finally {
+                // Schedule task
+                oxcox.disable(ctx, reason);
+                invalidateContextCache(ctx, credentials);
+                return TaskManager.getInstance().addJob(fsdm, "movefilestore", "move context " + ctx.getIdAsString() + " to filestore " + dst_filestore.getId(), ctx.getId().intValue());
+            } catch (StorageException e) {
+                throw new StorageException(e.getMessage());
+            } catch (RejectedExecutionException e) {
                 oxcox.enable(ctx);
+                throw e;
             }
         } catch (Throwable e) {
             logAndEnhanceException(e, credentials, ctx);
@@ -1736,4 +1733,21 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
     public boolean checkExists(final Context ctx, final Credentials credentials) throws RemoteException, InvalidDataException, StorageException, InvalidCredentialsException {
         return exists(ctx, credentials);
     }
+
+    // ------------------------- private methods -------------------------
+
+    /**
+     * Invalidate the context cache
+     *
+     * @param ctx The context
+     * @param credentials The credentials
+     */
+    private void invalidateContextCache(Context ctx, Credentials credentials) {
+        try {
+            ContextStorage.getInstance().invalidateContext(ctx.getId().intValue());
+            log(LogLevel.INFO, LOGGER, credentials, ctx.getIdAsString(), null, "Context {} successfully invalidated", ctx.getId());
+        } catch (OXException e) {
+            log(LogLevel.ERROR, LOGGER, credentials, ctx.getIdAsString(), e, "Error invalidating context {} in ox context storage", ctx.getId());
+        }
+    }
 }
