@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -105,7 +105,7 @@ public class DataFetcherMysql implements DataFetcher {
         StringBuilder sb = new StringBuilder();
         sb.append("SELECT ");
         for (TableColumnObject tco : column_objects) {
-            sb.append(tco.getName()).append(',');
+            sb.append('`').append(tco.getName()).append('`').append(',');
         }
         sb.delete(sb.length() - 1, sb.length());
         sb.append(" FROM ").append(to.getName()).append(" WHERE ").append(getMatchingColumn()).append(" = ?");
