@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -24,6 +24,7 @@ package com.openexchange.admin.rmi;
 import java.rmi.Remote;
 import java.rmi.RemoteException;
 import com.openexchange.admin.rmi.exceptions.StorageException;
+import com.openexchange.auth.Credentials;
 
 /**
  * {@link OXContextGroupInterface}
@@ -41,7 +42,8 @@ public interface OXContextGroupInterface extends Remote {
      * Deletes all data from the globaldb that is associated to the specified context group.
      *
      * @param contextGroupId The context group identifier
+     * @param auth Credentials for authenticating against server.
      * @throws RemoteException
      */
-    void deleteContextGroup(String contextGroupId) throws RemoteException, StorageException;
+    void deleteContextGroup(String contextGroupId, Credentials auth) throws RemoteException, StorageException;
 }
