@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -567,6 +567,8 @@ public interface OXUserInterface extends Remote {
      * @param context Context object.
      * @param auth Credentials for authenticating against server.
      * @param filestore_id The identifier of the file storage
+     * @param length The result size
+     * @param offset The offset in overall collection
      *
      * @return User[] with currently ONLY id set in each User.
      *
@@ -577,7 +579,7 @@ public interface OXUserInterface extends Remote {
      * @throws InvalidDataException If the data sent within the method contained invalid data.
      * @throws DatabaseUpdateException
      */
-    User[] listUsersWithOwnFilestore(final Context context, final Credentials auth, final Integer filestore_id) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException;
+    User[] listUsersWithOwnFilestore(final Context context, final Credentials auth, final Integer filestore_id, final Integer length, final Integer offset) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException;
 
     /**
      * Retrieve all users for a given context.
@@ -585,12 +587,11 @@ public interface OXUserInterface extends Remote {
      * a * is transformed into a %<br>
      * a % and a _ must be escaped by a \ (e.g. if you want to search for _doe, use the pattern \_doe
      *
-     * @param ctx
-     *            Context object.
-     * @param search_pattern
-     *            A pattern to search for
-     * @param auth
-     *            Credentials for authenticating against server.
+     * @param ctx The context
+     * @param search_pattern A pattern to search for
+     * @param auth The credentials for authenticating against server.
+     * @param length The result size
+     * @param offset The offset in overall collection
      * @return User[] with currently ONLY id set in each User.
      *
      * @throws RemoteException
@@ -600,7 +601,53 @@ public interface OXUserInterface extends Remote {
      * @throws InvalidDataException
      * @throws DatabaseUpdateException
      */
-    public User[] list(final Context ctx, final String search_pattern, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException;
+    public User[] list(final Context ctx, final String search_pattern, final Credentials auth, final Integer length, final Integer offset) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException;
+
+    /**
+     * Retrieve all users for a given context.
+     * The search pattern is directly transformed into a SQL LIKE string comparison, where<br>
+     * a * is transformed into a %<br>
+     * a % and a _ must be escaped by a \ (e.g. if you want to search for _doe, use the pattern \_doe
+     *
+     * @param ctx The context
+     * @param search_pattern A pattern to search for
+     * @param auth The credentials for authenticating against server
+     * @param includeGuests Whether to list guest users too
+     * @param excludeUsers Whether to list only guest users
+     * @param length The result size
+     * @param offset The offset in overall collection
+     * @return User[] with currently ONLY id set in each User.
+     *
+     * @throws RemoteException
+     * @throws StorageException
+     * @throws InvalidCredentialsException
+     * @throws NoSuchContextException
+     * @throws InvalidDataException
+     * @throws DatabaseUpdateException
+     */
+    public User[] list(final Context ctx, final String search_pattern, final Credentials auth, final boolean includeGuests, final boolean excludeUsers, Integer length, Integer offset) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException;
+
+    /**
+     * Retrieve all users for a given context.
+     * The search pattern is directly transformed into a SQL LIKE string comparison, where<br>
+     * a * is transformed into a %<br>
+     * a % and a _ must be escaped by a \ (e.g. if you want to search for _doe, use the pattern \_doe
+     *
+     * @param ctx The context
+     * @param search_pattern A pattern to search for
+     * @param auth The credentials for authenticating against server
+     * @param length The result size
+     * @param offset The offset in overall collection
+     * @return User[] with currently ONLY id set in each User.
+     *
+     * @throws RemoteException
+     * @throws StorageException
+     * @throws InvalidCredentialsException
+     * @throws NoSuchContextException
+     * @throws InvalidDataException
+     * @throws DatabaseUpdateException
+     */
+    public User[] listCaseInsensitive(final Context ctx, final String search_pattern, final Credentials auth, final Integer length, final Integer offset) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException;
 
     /**
      * Retrieve all users for a given context.
@@ -618,6 +665,8 @@ public interface OXUserInterface extends Remote {
      *            List guest users too
      * @param excludeUsers
      *            List only guest users
+     * @param length The result size
+     * @param offset The offset in overall collection
      * @return User[] with currently ONLY id set in each User.
      *
      * @throws RemoteException
@@ -627,57 +676,7 @@ public interface OXUserInterface extends Remote {
      * @throws InvalidDataException
      * @throws DatabaseUpdateException
      */
-    public User[] list(final Context ctx, final String search_pattern, final Credentials auth, final boolean includeGuests, final boolean excludeUsers) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException;
-
-    /**
-     * Retrieve all users for a given context.
-     * The search pattern is directly transformed into a SQL LIKE string comparison, where<br>
-     * a * is transformed into a %<br>
-     * a % and a _ must be escaped by a \ (e.g. if you want to search for _doe, use the pattern \_doe
-     *
-     * @param ctx
-     *            Context object.
-     * @param search_pattern
-     *            A pattern to search for
-     * @param auth
-     *            Credentials for authenticating against server.
-     * @return User[] with currently ONLY id set in each User.
-     *
-     * @throws RemoteException
-     * @throws StorageException
-     * @throws InvalidCredentialsException
-     * @throws NoSuchContextException
-     * @throws InvalidDataException
-     * @throws DatabaseUpdateException
-     */
-    public User[] listCaseInsensitive(final Context ctx, final String search_pattern, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException;
-
-    /**
-     * Retrieve all users for a given context.
-     * The search pattern is directly transformed into a SQL LIKE string comparison, where<br>
-     * a * is transformed into a %<br>
-     * a % and a _ must be escaped by a \ (e.g. if you want to search for _doe, use the pattern \_doe
-     *
-     * @param ctx
-     *            Context object.
-     * @param search_pattern
-     *            A pattern to search for
-     * @param auth
-     *            Credentials for authenticating against server.
-     * @param includeGuests
-     *            List guest users too
-     * @param excludeUsers
-     *            List only guest users
-     * @return User[] with currently ONLY id set in each User.
-     *
-     * @throws RemoteException
-     * @throws StorageException
-     * @throws InvalidCredentialsException
-     * @throws NoSuchContextException
-     * @throws InvalidDataException
-     * @throws DatabaseUpdateException
-     */
-    public User[] listCaseInsensitive(final Context ctx, final String search_pattern, final Credentials auth, final boolean includeGuests, final boolean excludeUsers) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException;
+    public User[] listCaseInsensitive(final Context ctx, final String search_pattern, final Credentials auth, final boolean includeGuests, final boolean excludeUsers, final Integer length, final Integer offset) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException;
 
     /**
      * Retrieve all users for a given context. The same as calling list with a search_pattern of "*"
@@ -775,6 +774,6 @@ public interface OXUserInterface extends Remote {
      * @throws NoSuchContextException
      * @throws InvalidDataException
      */
-    public User[] listByAliasDomain(Context context, String aliasDomain, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException;
+    public User[] listByAliasDomain(Context context, String aliasDomain, Credentials auth, final Integer length, final Integer offset) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException;
 
 }
