@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,8 +21,8 @@
 
 package com.openexchange.admin.rmi.exceptions;
 
-import java.security.SecureRandom;
 import java.util.concurrent.atomic.AtomicInteger;
+import com.openexchange.java.CryptoUtil;
 
 /**
  * {@link AbstractAdminRmiException} - Super class for all administrative RMI exceptions.
@@ -34,7 +34,7 @@ public abstract class AbstractAdminRmiException extends Exception {
 
     private static final long serialVersionUID = 8462133304948138631L;
 
-    private final static int EXCEPTION_ID = new SecureRandom().nextInt();
+    private final static int EXCEPTION_ID = CryptoUtil.getSecureRandom().nextInt();
     private final static AtomicInteger COUNTER = new AtomicInteger(0);
 
     /**
