@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -318,6 +318,7 @@ public class AdminDaemon implements AdminDaemonService {
             final com.openexchange.admin.rmi.impl.OXUtil oxutil_v2 = new com.openexchange.admin.rmi.impl.OXUtil();
             final OXAdminCoreImpl oxadmincore = new OXAdminCoreImpl();
             final OXTaskMgmtImpl oxtaskmgmt = new OXTaskMgmtImpl();
+            final com.openexchange.admin.rmi.impl.OXSecondaryAccount oxaccount_v2 = new com.openexchange.admin.rmi.impl.OXSecondaryAccount();
 
             Dictionary<String, Object> properties = new Hashtable<String, Object>(2);
             properties.put("RMIName", com.openexchange.admin.rmi.OXUserInterface.RMI_NAME);
@@ -346,6 +347,10 @@ public class AdminDaemon implements AdminDaemonService {
             properties = new Hashtable<String, Object>(2);
             properties.put("RMIName", com.openexchange.admin.rmi.OXUtilInterface.RMI_NAME);
             services.add(context.registerService(Remote.class, oxutil_v2, properties));
+
+            properties = new Hashtable<String, Object>(2);
+            properties.put("RMIName", com.openexchange.admin.rmi.OXSecondaryAccountInterface.RMI_NAME);
+            services.add(context.registerService(Remote.class, oxaccount_v2, properties));
         } catch (RemoteException e) {
             LOG.error("Error creating RMI registry!", e);
         } catch (StorageException e) {
