@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -61,9 +61,7 @@ public class CreateOXFolderTables extends AbstractCreateTableImpl {
        + "INDEX `parentIndex` (`cid`, `parent`),"
        + "INDEX `typeIndex` (`cid`, `type`),"
        + "INDEX `moduleIndex` (`cid`, `module`),"
-       + "INDEX `lastModifiedIndex` (`cid`, `changing_date`, `module`),"
-       + "FOREIGN KEY (`cid`, `created_from`) REFERENCES user (`cid`, `id`),"
-       + "FOREIGN KEY (`cid`, `changed_from`) REFERENCES user (`cid`, `id`)"
+       + "INDEX `lastModifiedIndex` (`cid`, `changing_date`, `module`)"
      + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     private static final String createOxfolderPermissionsTable = "CREATE TABLE `oxfolder_permissions` ("
@@ -80,16 +78,14 @@ public class CreateOXFolderTables extends AbstractCreateTableImpl {
        + "`type` INT4 UNSIGNED NOT NULL default '0',"
        + "`sharedParentFolder` INT4 UNSIGNED,"
        + "PRIMARY KEY  (`cid`, `fuid`, `permission_id`, `system`),"
-       + "INDEX `principal` (`cid`, `permission_id`, `fuid`),"
-       + "FOREIGN KEY (`cid`, `fuid`) REFERENCES oxfolder_tree (`cid`, `fuid`)"
+       + "INDEX `principal` (`cid`, `permission_id`, `fuid`)"
      + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     private static final String createOxfolderSpecialfoldersTable = "CREATE TABLE `oxfolder_specialfolders` ("
         + "`tag` VARCHAR(16) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL,"
         + "`cid` INT4 UNSIGNED NOT NULL,"
         + "`fuid` INT4 UNSIGNED NOT NULL,"
-        + "PRIMARY KEY (`cid`,`fuid`,`tag`),"
-        + "FOREIGN KEY (`cid`, `fuid`) REFERENCES oxfolder_tree (`cid`, `fuid`)"
+        + "PRIMARY KEY (`cid`,`fuid`,`tag`)"
       + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     private static final String createOxfolderUserfoldersTable = "CREATE TABLE `oxfolder_userfolders` ("
@@ -106,8 +102,7 @@ public class CreateOXFolderTables extends AbstractCreateTableImpl {
        + "`cid` INT4 UNSIGNED NOT NULL,"
        + "`module` TINYINT UNSIGNED NOT NULL,"
        + "`fuid` INT4 UNSIGNED NOT NULL,"
-       + "PRIMARY KEY (`owner`, `cid`, `module`, `fuid`),"
-       + "FOREIGN KEY (`cid`, `fuid`) REFERENCES oxfolder_tree (`cid`, `fuid`)"
+       + "PRIMARY KEY (`owner`, `cid`, `module`, `fuid`)"
      + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     private static final String createDelOxfolderTreeTable = "CREATE TABLE `del_oxfolder_tree` ("
@@ -130,9 +125,7 @@ public class CreateOXFolderTables extends AbstractCreateTableImpl {
        + "INDEX `parentIndex` (`cid`, `parent`),"
        + "INDEX `typeIndex` (`cid`, `type`),"
        + "INDEX `moduleIndex` (`cid`, `module`),"
-       + "INDEX `lastModifiedIndex` (`cid`, `changing_date`, `module`),"
-       + "FOREIGN KEY (`cid`, `created_from`) REFERENCES user (`cid`, `id`),"
-       + "FOREIGN KEY (`cid`, `changed_from`) REFERENCES user (`cid`, `id`)"
+       + "INDEX `lastModifiedIndex` (`cid`, `changing_date`, `module`)"
      + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     private static final String createDelOxfolderPermissionsTable = "CREATE TABLE `del_oxfolder_permissions` ("
@@ -149,8 +142,7 @@ public class CreateOXFolderTables extends AbstractCreateTableImpl {
        + "`type` INT4 UNSIGNED NOT NULL default '0',"
        + "`sharedParentFolder` INT4 UNSIGNED,"
        + "PRIMARY KEY  (`cid`,`fuid`,`permission_id`,`system`),"
-       + "INDEX `principal` (`cid`, `permission_id`, `fuid`),"
-       + "FOREIGN KEY (`cid`, `fuid`) REFERENCES del_oxfolder_tree (`cid`, `fuid`)"
+       + "INDEX `principal` (`cid`, `permission_id`, `fuid`)"
      + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     private static final String createOxfolderLockTable = "CREATE TABLE `oxfolder_lock` ("
