@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -43,8 +43,7 @@ public class CreateSettingsTables extends AbstractCreateTableImpl {
        + "cid INT4 UNSIGNED NOT NULL,"
        + "user INT4 UNSIGNED NOT NULL,"
        + "permissions INT4 UNSIGNED NOT NULL,"
-       + "PRIMARY KEY (cid, user),"
-       + "FOREIGN KEY (cid, user) REFERENCES user (cid, id)"
+       + "PRIMARY KEY (cid, user)"
      + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     private static final String createUserSettingMailTable = "CREATE TABLE user_setting_mail ("
@@ -64,8 +63,7 @@ public class CreateSettingsTables extends AbstractCreateTableImpl {
        + "confirmed_ham VARCHAR(128) NOT NULL,"
        + "upload_quota INT4 DEFAULT -1,"
        + "upload_quota_per_file INT4 DEFAULT -1,"
-       + "PRIMARY KEY (cid, user),"
-       + "FOREIGN KEY (cid, user) REFERENCES user (cid, id)"
+       + "PRIMARY KEY (cid, user)"
      + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     private static final String createUserSettingMailSignatureTable = "CREATE TABLE user_setting_mail_signature ("
@@ -73,23 +71,20 @@ public class CreateSettingsTables extends AbstractCreateTableImpl {
        + "user INT4 UNSIGNED NOT NULL,"
        + "id VARCHAR(64) NOT NULL,"
        + "signature VARCHAR(1024) NOT NULL,"
-       + "PRIMARY KEY (cid, user, id),"
-       + "FOREIGN KEY (cid, user) REFERENCES user_setting_mail (cid, user)"
+       + "PRIMARY KEY (cid, user, id)"
      + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     private static final String createUserSettingSpellcheckTable = "CREATE TABLE user_setting_spellcheck ("
        + "cid INT4 UNSIGNED NOT NULL,"
        + "user INT4 UNSIGNED NOT NULL,"
        + "user_dic TEXT,"
-       + "PRIMARY KEY (cid, user),"
-       + "FOREIGN KEY (cid, user) REFERENCES user (cid, id)"
+       + "PRIMARY KEY (cid, user)"
      + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     private static final String createUserSettingAdminTable = "CREATE TABLE user_setting_admin ("
        + "cid INT4 UNSIGNED NOT NULL,"
        + "user INT4 UNSIGNED NOT NULL,"
-       + "PRIMARY KEY (cid, user),"
-       + "FOREIGN KEY (cid, user) REFERENCES user (cid, id)"
+       + "PRIMARY KEY (cid, user)"
      + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     private static final String createUserSettingTable = "CREATE TABLE user_setting ("
@@ -111,8 +106,7 @@ public class CreateSettingsTables extends AbstractCreateTableImpl {
         + "contactCollectOnMailAccess BOOL DEFAULT TRUE,"
         + "folderTree INT4,"
         + "uuid BINARY(16) NOT NULL,"
-        + "PRIMARY KEY (cid, user, uuid),"
-        + "FOREIGN KEY(cid, user) REFERENCES user(cid, id)"
+        + "PRIMARY KEY (cid, user, uuid)"
       + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     /**
