@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -66,8 +66,11 @@ import com.openexchange.database.CreateTableService;
 import com.openexchange.database.DatabaseService;
 import com.openexchange.database.JdbcProperties;
 import com.openexchange.filestore.FileStorageUnregisterListenerRegistry;
+import com.openexchange.group.GroupService;
 import com.openexchange.groupware.filestore.FileLocationHandler;
 import com.openexchange.groupware.userconfiguration.PermissionConfigurationChecker;
+import com.openexchange.imagetransformation.ImageMetadataService;
+import com.openexchange.imagetransformation.ImageTransformationService;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.osgi.RankingAwareNearRegistryServiceTracker;
@@ -75,6 +78,7 @@ import com.openexchange.osgi.RankingAwareRegistryServiceTrackerCustomizer;
 import com.openexchange.osgi.RegistryServiceTrackerCustomizer;
 import com.openexchange.password.mechanism.PasswordMechRegistry;
 import com.openexchange.pluginsloaded.PluginsLoadedService;
+import com.openexchange.session.ObfuscatorService;
 import com.openexchange.sessiond.SessiondService;
 import com.openexchange.snippet.QuotaAwareSnippetService;
 import com.openexchange.threadpool.ThreadPoolService;
@@ -129,11 +133,15 @@ public class AdminActivator extends HousekeepingActivator {
         track(CacheService.class, new RegistryServiceTrackerCustomizer<CacheService>(context, AdminServiceRegistry.getInstance(), CacheService.class));
         track(CapabilityService.class, new RegistryServiceTrackerCustomizer<CapabilityService>(context, AdminServiceRegistry.getInstance(), CapabilityService.class));
         track(SessiondService.class, new RegistryServiceTrackerCustomizer<SessiondService>(context, AdminServiceRegistry.getInstance(), SessiondService.class));
+        track(ObfuscatorService.class, new RegistryServiceTrackerCustomizer<ObfuscatorService>(context, AdminServiceRegistry.getInstance(), ObfuscatorService.class));
         track(PermissionConfigurationChecker.class, new RegistryServiceTrackerCustomizer<PermissionConfigurationChecker>(context, AdminServiceRegistry.getInstance(), PermissionConfigurationChecker.class));
         track(Remote.class, new OXContextInterfaceTracker(context)).open();
         UserServiceInterceptorRegistry interceptorRegistry = new UserServiceInterceptorRegistry(context);
         track(UserServiceInterceptor.class, interceptorRegistry);
         track(UserService.class, new RegistryServiceTrackerCustomizer<UserService>(context, AdminServiceRegistry.getInstance(), UserService.class));
+        track(GroupService.class, new RegistryServiceTrackerCustomizer<GroupService>(context, AdminServiceRegistry.getInstance(), GroupService.class));
+        track(ImageTransformationService.class, new RegistryServiceTrackerCustomizer<ImageTransformationService>(context, AdminServiceRegistry.getInstance(), ImageTransformationService.class));
+        track(ImageMetadataService.class, new RegistryServiceTrackerCustomizer<ImageMetadataService>(context, AdminServiceRegistry.getInstance(), ImageMetadataService.class));
         track(FileStorageUnregisterListenerRegistry.class, new RegistryServiceTrackerCustomizer<FileStorageUnregisterListenerRegistry>(context, AdminServiceRegistry.getInstance(), FileStorageUnregisterListenerRegistry.class));
         track(PluginsLoadedService.class, new RegistryServiceTrackerCustomizer<PluginsLoadedService>(context, AdminServiceRegistry.getInstance(), PluginsLoadedService.class));
         track(QuotaAwareSnippetService.class, new RankingAwareRegistryServiceTrackerCustomizer<QuotaAwareSnippetService>(context, AdminServiceRegistry.getInstance(), QuotaAwareSnippetService.class));
