@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -63,7 +63,7 @@ public final class AuthenticatorImpl implements Authenticator, Reloadable {
         return configService.getBoolProperty("MASTER_AUTHENTICATION_DISABLED", false);
     }
 
-    private com.openexchange.admin.rmi.dataobjects.Credentials toCreds(Credentials authdata) {
+    private static com.openexchange.admin.rmi.dataobjects.Credentials toCreds(Credentials authdata) {
         return new com.openexchange.admin.rmi.dataobjects.Credentials(authdata.getLogin(), authdata.getPassword());
     }
 
@@ -80,11 +80,7 @@ public final class AuthenticatorImpl implements Authenticator, Reloadable {
     public void doAuthentication(final Credentials authdata) throws OXException {
         try {
             BasicAuthenticator.createNonPluginAwareAuthenticator().doAuthentication(toCreds(authdata));
-        } catch (InvalidCredentialsException e) {
-            final OXException oxe = OXException.general(e.getMessage());
-            oxe.setStackTrace(e.getStackTrace());
-            throw oxe;
-        } catch (StorageException e) {
+        } catch (InvalidCredentialsException | StorageException e) {
             final OXException oxe = OXException.general(e.getMessage());
             oxe.setStackTrace(e.getStackTrace());
             throw oxe;
@@ -104,11 +100,7 @@ public final class AuthenticatorImpl implements Authenticator, Reloadable {
             } else {
                 BasicAuthenticator.createNonPluginAwareAuthenticator().doAuthentication(toCreds(authdata), new Context(Integer.valueOf(contextId)));
             }
-        } catch (InvalidCredentialsException e) {
-            final OXException oxe = OXException.general(e.getMessage());
-            oxe.setStackTrace(e.getStackTrace());
-            throw oxe;
-        } catch (StorageException e) {
+        } catch (InvalidCredentialsException | StorageException e) {
             final OXException oxe = OXException.general(e.getMessage());
             oxe.setStackTrace(e.getStackTrace());
             throw oxe;
@@ -119,11 +111,7 @@ public final class AuthenticatorImpl implements Authenticator, Reloadable {
     public void doUserAuthentication(final Credentials authdata, final int contextId) throws OXException {
         try {
             BasicAuthenticator.createNonPluginAwareAuthenticator().doUserAuthentication(toCreds(authdata), new Context(Integer.valueOf(contextId)));
-        } catch (InvalidCredentialsException e) {
-            final OXException oxe = OXException.general(e.getMessage());
-            oxe.setStackTrace(e.getStackTrace());
-            throw oxe;
-        } catch (StorageException e) {
+        } catch (InvalidCredentialsException | StorageException e) {
             final OXException oxe = OXException.general(e.getMessage());
             oxe.setStackTrace(e.getStackTrace());
             throw oxe;
