@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -52,7 +52,6 @@ public class AdminProperties {
         public static final String AUTO_LOWERCASE = "AUTO_TO_LOWERCASE_UID";
         public static final String CHECK_NOT_ALLOWED_NAMES = "CHECK_GROUP_UID_FOR_NOT_ALLOWED_NAMES";
         public static final String NOT_ALLOWED_NAMES = "NOT_ALLOWED_GROUP_UID_NAMES";
-        public static final String GID_NUMBER_START = "GID_NUMBER_START";
     }
 
     /**
@@ -101,7 +100,6 @@ public class AdminProperties {
      */
     public static class User {
 
-        public static final String UID_NUMBER_START = "UID_NUMBER_START";
         public static final String CHECK_NOT_ALLOWED_CHARS = "CHECK_USER_UID_FOR_NOT_ALLOWED_CHARS";
         public static final String AUTO_LOWERCASE = "AUTO_TO_LOWERCASE_UID";
         public static final String CHECK_NOT_ALLOWED_NAMES = "CHECK_USER_UID_FOR_NOT_ALLOWED_NAMES";
@@ -113,6 +111,7 @@ public class AdminProperties {
         public static final String ENABLE_ADMIN_MAIL_CHECKS = "com.openexchange.admin.enableAdminMailChecks";
         public static final String ADDITIONAL_EMAIL_CHECK_REGEX = "com.openexchange.admin.additionalEmailCheckRegex";
         public static final String ADDITIONAL_CONFIG_CHECK_REGEX = "com.openexchange.admin.additionalConfigCheckRegex";
+        public static final String AUTO_DELETE_GUESTS_USING_FILESTORE = "com.openexchange.admin.autoDeleteGuestsUsingFilestore";
     }
 
     /**
@@ -140,10 +139,12 @@ public class AdminProperties {
                 // Scopes given
                 for (String scope : optionalScopes.get()) {
                     com.openexchange.config.cascade.ConfigProperty<T> configProperty = view.property(scope, propertyName, coerceTo);
-                    if (false == configProperty.isDefined()) {
+
+                    T value = configProperty.get();
+                    if (value == null) {
                         continue;
                     }
-                    return configProperty.get();
+                    return value;
                 }
             } else {
                 // No scopes given. Follow regular search path
