@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -59,7 +59,7 @@ import com.openexchange.groupware.userconfiguration.PermissionConfigurationCheck
 import com.openexchange.log.LogProperties;
 
 /**
- * {@link OXCommonImpl} - General abstraction class used by all impl classes
+ * {@link OXCommonImpl} - General abstraction class used by all implementation classes.
  *
  * @author d7
  * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
@@ -68,7 +68,7 @@ public abstract class OXCommonImpl {
 
     private static final String CONFIG_NAMESPACE = "config";
 
-    private final static org.slf4j.Logger LOGGER = org.slf4j.LoggerFactory.getLogger(OXCommonImpl.class);
+    private static final org.slf4j.Logger LOGGER = org.slf4j.LoggerFactory.getLogger(OXCommonImpl.class);
 
     protected final OXToolStorageInterface tool;
 
@@ -83,10 +83,11 @@ public abstract class OXCommonImpl {
 
     /**
      * Initializes a new {@link OXCommonImpl}.
-     * 
+     *
      * @throws StorageException In case the PermissionConfigurationChecker service is unavailable
      */
-    public OXCommonImpl() {
+    protected OXCommonImpl() {
+        super();
         tool = OXToolStorageInterface.getInstance();
     }
 
@@ -103,7 +104,7 @@ public abstract class OXCommonImpl {
         }
     }
 
-    protected final void contextcheck(final Context ctx) throws InvalidCredentialsException {
+    protected static final void contextcheck(final Context ctx) throws InvalidCredentialsException {
         if (null == ctx || null == ctx.getId()) {
             final InvalidCredentialsException e = new InvalidCredentialsException("Client sent invalid context data object");
             LOGGER.error("", e);
@@ -247,7 +248,7 @@ public abstract class OXCommonImpl {
 
     /**
      * Checks whether the context exists and updates the schema if needed
-     * 
+     *
      * @param ctx
      * @throws StorageException
      * @throws com.openexchange.admin.rmi.exceptions.DatabaseUpdateException
@@ -417,7 +418,7 @@ public abstract class OXCommonImpl {
     }
 
     /**
-     * Log a message with given log properties in MDC
+     * Logs a message with given log properties for Mapped Diagnostic Context (MDC).
      *
      * @param level The log level
      * @param logger The logger
@@ -429,35 +430,11 @@ public abstract class OXCommonImpl {
      * @param args The arguments to log
      */
     public static void log(LogLevel level, org.slf4j.Logger logger, Credentials creds, String contextId, String objectId, Exception e, String message, Object... args) {
-        if (null == level || null == logger) {
-            LOGGER.error("LogLevel and logger instance must not be null!");
-            return;
-        }
-        LogProperties.putProvisioningLogProperties(getAdminName(creds), null, contextId, objectId);
-        switch (level) {
-            case TRACE:
-                logger.trace(message, args, e);
-                break;
-            case DEBUG:
-                logger.debug(message, args, e);
-                break;
-            case INFO:
-                logger.info(message, args, e);
-                break;
-            case WARNING:
-                logger.warn(message, args, e);
-                break;
-            case ERROR:
-                logger.error(message, args, e);
-                break;
-            default:
-                LOGGER.error("Invalid log level {}", level.name());
-                break;
-        }
+        doLog(level, logger, creds, contextId, objectId, e, message, args);
     }
 
     /**
-     * Log a message with given log properties in MDC
+     * Logs a message with given log properties in MDC
      *
      * @param level The log level
      * @param logger The logger
@@ -468,11 +445,11 @@ public abstract class OXCommonImpl {
      * @param message The message to log
      */
     public static void log(LogLevel level, org.slf4j.Logger logger, Credentials creds, String contextId, String objectId, Exception e, String message) {
-        log(level, logger, creds, contextId, objectId, e, message, new Object[] {});
+        doLog(level, logger, creds, contextId, objectId, e, message);
     }
 
     /**
-     * Log a message with given log properties in MDC
+     * Logs a message with given log properties in MDC
      *
      * @param level The log level
      * @param logger The logger
@@ -483,11 +460,11 @@ public abstract class OXCommonImpl {
      * @param args The arguments to log
      */
     public static void log(LogLevel level, org.slf4j.Logger logger, Credentials creds, String contextId, Exception e, String message, Object... args) {
-        log(level, logger, creds, contextId, null, e, message, args);
+        doLog(level, logger, creds, contextId, null, e, message, args);
     }
 
     /**
-     * Log a message with given log properties in MDC
+     * Logs a message with given log properties in MDC
      *
      * @param level The log level
      * @param logger The logger
@@ -497,11 +474,11 @@ public abstract class OXCommonImpl {
      * @param message The message to log
      */
     public static void log(LogLevel level, org.slf4j.Logger logger, Credentials creds, String contextId, Exception e, String message) {
-        log(level, logger, creds, contextId, null, e, message, new Object[] {});
+        doLog(level, logger, creds, contextId, null, e, message);
     }
 
     /**
-     * Log a message with given log properties in MDC
+     * Logs a message with given log properties in MDC
      *
      * @param level The log level
      * @param logger The logger
@@ -511,11 +488,11 @@ public abstract class OXCommonImpl {
      * @param args The arguments to log
      */
     public static void log(LogLevel level, org.slf4j.Logger logger, Credentials creds, Exception e, String message, Object... args) {
-        log(level, logger, creds, null, null, e, message, args);
+        doLog(level, logger, creds, null, null, e, message, args);
     }
 
     /**
-     * Log a message with given log properties in MDC
+     * Logs a message with given log properties in MDC
      *
      * @param level The log level
      * @param logger The logger
@@ -524,7 +501,71 @@ public abstract class OXCommonImpl {
      * @param message The message to log
      */
     public static void log(LogLevel level, org.slf4j.Logger logger, Credentials creds, Exception e, String message) {
-        log(level, logger, creds, null, null, e, message, new Object[] {});
+        doLog(level, logger, creds, null, null, e, message);
+    }
+
+    /**
+     * Logs a message with given log properties for Mapped Diagnostic Context (MDC).
+     *
+     * @param level The log level
+     * @param logger The logger
+     * @param creds The credentials to put in MDC
+     * @param contextId The affected context's identifier to put in MDC
+     * @param objectId The affected object's identifier to put in MDC
+     * @param e The exception to log
+     * @param message The message to log
+     * @param args The arguments to log
+     */
+    private static void doLog(LogLevel level, org.slf4j.Logger logger, Credentials creds, String contextId, String objectId, Exception e, String message, Object... args) {
+        if (null == level || null == logger) {
+            LOGGER.error("LogLevel and logger instance must not be null!");
+            return;
+        }
+
+        Object[] logArgs = appendExceptionToLogArguments(e, args);
+        LogProperties.putProvisioningLogProperties(getAdminName(creds), null, contextId, objectId);
+        try {
+            switch (level) {
+                case TRACE:
+                    logger.trace(message, logArgs);
+                    break;
+                case DEBUG:
+                    logger.debug(message, logArgs);
+                    break;
+                case INFO:
+                    logger.info(message, logArgs);
+                    break;
+                case WARNING:
+                    logger.warn(message, logArgs);
+                    break;
+                case ERROR:
+                    logger.error(message, logArgs);
+                    break;
+                default:
+                    LOGGER.error("Invalid log level {}", level.name());
+                    break;
+            }
+        } finally {
+            LogProperties.removeProvisioningLogProperties();
+        }
+    }
+
+    private static Object[] appendExceptionToLogArguments(Exception e, Object... args) {
+        if (null == e) {
+            // No exception given
+            return args;
+        }
+
+        if (null == args || 0 == args.length) {
+            // No log arguments given. Just return exception as argument.
+            return new Object[] { e };
+        }
+
+        // Append exception instance to tail of the array
+        Object[] logArgs = new Object[args.length + 1];
+        System.arraycopy(args, 0, logArgs, 0, args.length);
+        logArgs[args.length] = e;
+        return logArgs;
     }
 
     /**
