@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 
 package com.openexchange.admin.rmi.impl;
 
+import static com.openexchange.java.Autoboxing.I;
 import java.rmi.RemoteException;
 import java.util.concurrent.ExecutionException;
 import com.openexchange.admin.daemons.ClientAdminThread;
@@ -129,6 +130,21 @@ public class OXTaskMgmtImpl extends OXCommonImpl implements OXTaskMgmtInterface
         }
     }
 
+    @Override
+    public String getJob(final Context ctx, final Credentials cred, final int jobId) throws RemoteException, InvalidDataException, InvalidCredentialsException, StorageException {
+        try {
+            doAuth(cred, ctx);
+            if (cache.isMasterAdmin(cred)) {
+                return TaskManager.getInstance().getJob(null, I(jobId));
+            }
+            contextcheck(ctx);
+            return TaskManager.getInstance().getJob(ctx.getId(), I(jobId));
+        } catch (Throwable e) {
+            logAndEnhanceException(e, cred, ctx.getIdAsString(), null);
+            throw e;
+        }
+    }
+
     @Override
     public Object getTaskResults(final Context ctx, final Credentials cred, final int id) throws RemoteException, InvalidCredentialsException, StorageException, InterruptedException, ExecutionException, InvalidDataException {
         try {
