@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -450,17 +450,6 @@ public abstract class OXToolStorageInterface {
 
     public abstract int getDefaultGroupForContextWithOutConnection(final Context ctx) throws StorageException;
 
-    /**
-     * Gets the system's GID for specified group.
-     *
-     * @param ctx The context
-     * @param group_id The group ID
-     * @param con A connection with at least read-only permission
-     * @return The system's GID for specified group or <code>-1</code> if no GID is set.
-     * @throws StorageException If a storage error occurs or group does not exist
-     */
-    public abstract int getGidNumberOfGroup(final Context ctx, final int group_id, final Connection con) throws StorageException;
-
     public abstract int getGroupIDByGroupname(Context ctx, String groupName) throws StorageException, NoSuchGroupException;
 
     public abstract String getGroupnameByGroupID(final Context ctx, final int group_id) throws StorageException;
