@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -92,32 +92,6 @@ public class OXContextMySQLStorageCommon {
                 return 20;
             }
         });
-        startValues.put("sequence_uid_number", new StartNumberProvider() {
-
-            @Override
-            public int getStartValue() {
-                int startnum = Integer.parseInt(prop.getUserProp(AdminProperties.User.UID_NUMBER_START, "-1"));
-                if (startnum > 0) {
-                    // we use the uid number feature
-                    // set the start number in the sequence for uid_numbers
-                    return startnum;
-                }
-                return 0;
-            }
-        });
-        startValues.put("sequence_gid_number", new StartNumberProvider() {
-
-            @Override
-            public int getStartValue() {
-                int startnum = Integer.parseInt(prop.getGroupProp(AdminProperties.Group.GID_NUMBER_START, "-1"));
-                if (startnum > 0) {
-                    // we use the gid number feature
-                    // set the start number in the sequence for gid_numbers
-                    return startnum;
-                }
-                return 0;
-            }
-        });
         this.startValues = startValues;
     }
 
@@ -302,20 +276,13 @@ public class OXContextMySQLStorageCommon {
         return retval.values().toArray(new Context[retval.size()]);
     }
 
-    public final void createStandardGroupForContext(final int context_id, final Connection ox_write_con, final String display_name, final int group_id, final int gid_number) throws SQLException {
-        // TODO: this must be defined somewhere else
-        final int NOGROUP = 65534;
-        final PreparedStatement group_stmt = ox_write_con.prepareStatement("INSERT INTO groups (cid, id, identifier, displayname,lastModified,gidNumber) VALUES (?,?,'users',?,?,?);");
+    public final void createStandardGroupForContext(final int context_id, final Connection ox_write_con, final String display_name, final int group_id) throws SQLException {
+        final PreparedStatement group_stmt = ox_write_con.prepareStatement("INSERT INTO `groups` (cid, id, identifier, displayname, lastModified) VALUES (?,?,'users',?,?);");
         try {
             group_stmt.setInt(1, context_id);
             group_stmt.setInt(2, group_id);
             group_stmt.setString(3, display_name);
             group_stmt.setLong(4, System.currentTimeMillis());
-            if (Integer.parseInt(prop.getGroupProp(AdminProperties.Group.GID_NUMBER_START, "-1")) > 0) {
-                group_stmt.setInt(5, gid_number);
-            } else {
-                group_stmt.setInt(5, NOGROUP);
-            }
             group_stmt.executeUpdate();
         } finally {
             closeSQLStuff(group_stmt);
