@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -32,7 +32,6 @@ import java.util.ArrayList;
 import java.util.LinkedList;
 import java.util.List;
 import com.openexchange.admin.daemons.ClientAdminThread;
-import com.openexchange.admin.properties.AdminProperties;
 import com.openexchange.admin.rmi.dataobjects.Context;
 import com.openexchange.admin.rmi.dataobjects.Group;
 import com.openexchange.admin.rmi.dataobjects.User;
@@ -78,7 +77,7 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
     private void changeLastModifiedOnGroup(int ctxId, int groupId, Connection con) throws SQLException {
         PreparedStatement stmt = null;
         try {
-            stmt = con.prepareStatement("UPDATE groups SET lastModified=? WHERE cid=? AND id=?;");
+            stmt = con.prepareStatement("UPDATE `groups` SET `lastModified`=? WHERE `cid`=? AND `id`=?;");
             stmt.setLong(1, System.currentTimeMillis());
             stmt.setInt(2, ctxId);
             stmt.setInt(3, groupId);
@@ -92,24 +91,19 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
         PreparedStatement stmt = null;
         ResultSet result = null;
         try {
-            stmt = con.prepareStatement("SELECT identifier,displayName,gidNumber FROM groups WHERE id=? AND cid=?");
+            stmt = con.prepareStatement("SELECT `identifier`,`displayName` FROM `groups` WHERE `id`=? AND `cid`=?");
             stmt.setInt(1, groupId);
             stmt.setInt(2, ctxId);
             result = stmt.executeQuery();
-            int gidNumber = -1;
 
-            if (result.next()) {
-                gidNumber = result.getInt("gidNumber");
-            }
             stmt.close();
 
-            stmt = con.prepareStatement("INSERT into del_groups (id,cid,lastModified,identifier,displayName,gidNumber) VALUES (?,?,?,?,?,?)");
+            stmt = con.prepareStatement("INSERT into `del_groups` (`id`,`cid`,`lastModified`,`identifier`,`displayName`) VALUES (?,?,?,?,?)");
             stmt.setInt(1, groupId);
             stmt.setInt(2, ctxId);
             stmt.setLong(3, System.currentTimeMillis());
             stmt.setString(4, "");
             stmt.setString(5, "");
-            stmt.setInt(6, gidNumber);
             stmt.executeUpdate();
         } finally {
             Databases.closeSQLStuff(result, stmt);
@@ -121,7 +115,7 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
         ResultSet rs = null;
         final int context_ID = i(ctx.getId());
         try {
-            prep_list = con.prepareStatement("SELECT cid,identifier,displayName FROM groups WHERE groups.cid = ? AND groups.id = ?");
+            prep_list = con.prepareStatement("SELECT `cid`,`identifier`,`displayName` FROM `groups` WHERE groups.cid = ? AND groups.id = ?");
             prep_list.setInt(1, context_ID);
             prep_list.setInt(2, i(grp.getId()));
             rs = prep_list.executeQuery();
@@ -149,7 +143,7 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
         PreparedStatement stmt = null;
         final int ctxId = i(ctx.getId());
         try {
-            stmt = con.prepareStatement("SELECT member FROM groups_member WHERE cid=? AND id=?");
+            stmt = con.prepareStatement("SELECT `member` FROM `groups_member` WHERE `cid`=? AND `id`=?");
             stmt.setInt(1, ctxId);
             stmt.setInt(2, groupId);
             ResultSet result = stmt.executeQuery();
@@ -197,7 +191,7 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
         PreparedStatement stmt = null;
         try {
             con.setAutoCommit(false);
-            stmt = con.prepareStatement("INSERT INTO groups_member VALUES (?,?,?);");
+            stmt = con.prepareStatement("INSERT INTO `groups_member` VALUES (?,?,?);");
             stmt.setInt(1, ctxId);
             stmt.setInt(2, groupId);
             for (final User member : members) {
@@ -245,7 +239,7 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
             final int groupId = i(grp.getId());
             final String identifier = grp.getName();
             if (null != identifier) {
-                stmt = con.prepareStatement("UPDATE groups SET identifier=? WHERE cid=? AND id=?");
+                stmt = con.prepareStatement("UPDATE `groups` SET `identifier`=? WHERE `cid`=? AND `id`=?");
                 stmt.setString(1, identifier);
                 stmt.setInt(2, ctxId);
                 stmt.setInt(3, groupId);
@@ -254,7 +248,7 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
             }
             final String displayName = grp.getDisplayname();
             if (null != displayName) {
-                stmt = con.prepareStatement("UPDATE groups SET displayName=? WHERE cid=? AND id=?");
+                stmt = con.prepareStatement("UPDATE `groups` SET `displayName`=? WHERE `cid`=? AND `id`=?");
                 stmt.setString(1, displayName);
                 stmt.setInt(2, ctxId);
                 stmt.setInt(3, groupId);
@@ -265,12 +259,12 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
             final Integer[] memberIds = grp.getMembers();
             if (memberIds != null) {
                 // first delete all old members
-                stmt = con.prepareStatement("DELETE FROM groups_member WHERE cid=? AND id=?");
+                stmt = con.prepareStatement("DELETE FROM `groups_member` WHERE `cid`=? AND `id`=?");
                 stmt.setInt(1, ctxId);
                 stmt.setInt(2, groupId);
                 stmt.executeUpdate();
                 stmt.close();
-                stmt = con.prepareStatement("INSERT INTO groups_member (cid,id,member) VALUES (?,?,?)");
+                stmt = con.prepareStatement("INSERT INTO `groups_member` (`cid`,`id`,`member`) VALUES (?,?,?)");
                 for (final Integer memberId : memberIds) {
                     stmt.setInt(1, ctxId);
                     stmt.setInt(2, groupId);
@@ -282,7 +276,7 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
                 changeLastModifiedOfGroupMembers(ctx, con, memberIds);
             } else if (grp.isMembersset()) {
                 changeLastModifiedOfGroupMembers(ctx, con, getMembers(ctx, groupId, con));
-                stmt = con.prepareStatement("DELETE FROM groups_member WHERE cid=? AND id=?");
+                stmt = con.prepareStatement("DELETE FROM `groups_member` WHERE `cid`=? AND `id`=?");
                 stmt.setInt(1, ctxId);
                 stmt.setInt(2, groupId);
                 stmt.executeUpdate();
@@ -331,27 +325,17 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
             String displayName = group.getDisplayname();
             groupId = IDGenerator.getId(ctxId, com.openexchange.groupware.Types.PRINCIPAL, con);
             con.commit();
-            int gidNumber = -1;
-            if (Integer.parseInt(prop.getGroupProp(AdminProperties.Group.GID_NUMBER_START, "-1")) > 0) {
-                gidNumber = IDGenerator.getId(ctxId, com.openexchange.groupware.Types.GID_NUMBER, con);
-                con.commit();
-            }
-            stmt = con.prepareStatement("INSERT INTO groups (cid,id,identifier,displayName,lastModified,gidnumber) VALUES (?,?,?,?,?,?)");
+            stmt = con.prepareStatement("INSERT INTO `groups` (`cid`,`id`,`identifier`,`displayName`,`lastModified`) VALUES (?,?,?,?,?)");
             stmt.setInt(1, ctxId);
             stmt.setInt(2, groupId);
             stmt.setString(3, identifier);
             stmt.setString(4, displayName);
             stmt.setLong(5, System.currentTimeMillis());
-            if (-1 != gidNumber) {
-                stmt.setInt(6, gidNumber);
-            } else {
-                stmt.setInt(6, NOGROUP);
-            }
             stmt.executeUpdate();
             stmt.close();
             // check for members and add them
             if (group.getMembers() != null && group.getMembers().length > 0) {
-                stmt = con.prepareStatement("INSERT INTO groups_member (cid,id,member) VALUES (?,?,?)");
+                stmt = con.prepareStatement("INSERT INTO `groups_member` (`cid`,`id`,`member`) VALUES (?,?,?)");
                 stmt.setInt(1, ctxId);
                 stmt.setInt(2, groupId);
                 for (Integer memberId : group.getMembers()) {
@@ -407,7 +391,7 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
                     PreparedStatement stmt3 = null;
                     ResultSet rs3 = null;
                     try {
-                        stmt3 = con.prepareStatement("SELECT member FROM groups_member WHERE cid=? AND id=?");
+                        stmt3 = con.prepareStatement("SELECT `member` FROM `groups_member` WHERE `cid`=? AND `id`=?");
                         stmt3.setInt(1, ctxId);
                         stmt3.setInt(2, groupId);
                         rs3 = stmt3.executeQuery();
@@ -420,7 +404,7 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
                 }
 
                 changeLastModifiedOfGroupMembers(ctx, con, getMembers(ctx, groupId, con));
-                stmt1 = con.prepareStatement("DELETE FROM groups_member WHERE cid=? AND id=?");
+                stmt1 = con.prepareStatement("DELETE FROM `groups_member` WHERE `cid`=? AND `id`=?");
                 stmt1.setInt(1, ctxId);
                 stmt1.setInt(2, groupId);
                 stmt1.executeUpdate();
@@ -428,7 +412,7 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
 
                 createRecoveryData(ctxId, con, groupId);
 
-                stmt2 = con.prepareStatement("DELETE FROM groups WHERE cid=? AND id=?");
+                stmt2 = con.prepareStatement("DELETE FROM `groups` WHERE `cid`=? AND `id`=?");
                 stmt2.setInt(1, ctxId);
                 stmt2.setInt(2, groupId);
                 stmt2.executeUpdate();
@@ -487,7 +471,7 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
         PreparedStatement stmt = null;
         final int ctxId = i(ctx.getId());
         try {
-            stmt = con.prepareStatement("DELETE FROM del_groups WHERE cid=?");
+            stmt = con.prepareStatement("DELETE FROM `del_groups` WHERE `cid`=?");
             stmt.setInt(1, ctxId);
             stmt.executeUpdate();
         } catch (SQLException e) {
@@ -504,7 +488,7 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
         PreparedStatement stmt = null;
         final int ctxId = i(ctx.getId());
         try {
-            stmt = con.prepareStatement("DELETE FROM del_groups WHERE id=? AND cid=?");
+            stmt = con.prepareStatement("DELETE FROM `del_groups` WHERE `id`=? AND `cid`=?");
             stmt.setInt(1, groupId);
             stmt.setInt(2, ctxId);
             stmt.executeUpdate();
@@ -544,7 +528,7 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
         }
         PreparedStatement stmt = null;
         try {
-            stmt = con.prepareStatement("SELECT id FROM groups_member WHERE cid=? AND member=?");
+            stmt = con.prepareStatement("SELECT id FROM `groups_member` WHERE `cid`=? AND `member`=?");
             stmt.setInt(1, i(ctx.getId()));
             stmt.setInt(2, i(user.getId()));
             ResultSet result = stmt.executeQuery();
@@ -601,7 +585,7 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
         PreparedStatement stmt = null;
         ResultSet result = null;
         try {
-            stmt = con.prepareStatement("SELECT cid,id,identifier,displayName FROM groups WHERE cid=? AND (identifier LIKE ? OR displayName LIKE ?)");
+            stmt = con.prepareStatement("SELECT `cid`,`id`,`identifier`,`displayName` FROM `groups` WHERE `cid`=? AND (`identifier` LIKE ? OR `displayName` LIKE ?)");
             stmt.setInt(1, ctxId);
             stmt.setString(2, sqlPattern);
             stmt.setString(3, sqlPattern);
@@ -639,7 +623,7 @@ public class OXGroupMySQLStorage extends OXGroupSQLStorage implements OXMySQLDef
         PreparedStatement stmt = null;
         try {
             con.setAutoCommit(false);
-            stmt = con.prepareStatement("DELETE FROM groups_member WHERE cid=? AND id=? AND member=?");
+            stmt = con.prepareStatement("DELETE FROM `groups_member` WHERE `cid`=? AND `id`=? AND `member`=?");
             stmt.setInt(1, ctxId);
             stmt.setInt(2, groupId);
             for (User member : members) {
