@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -61,7 +61,6 @@ import com.openexchange.admin.storage.sqlStorage.OXAdminPoolDBPool;
 import com.openexchange.admin.storage.sqlStorage.OXAdminPoolInterface;
 import com.openexchange.caching.CacheService;
 import com.openexchange.config.ConfigurationService;
-import com.openexchange.config.ConfigurationServices;
 import com.openexchange.database.Databases;
 import com.openexchange.database.JdbcProperties;
 import com.openexchange.exception.OXException;
@@ -323,7 +322,7 @@ public class AdminCache {
                 UserModuleAccess us = new UserModuleAccess();
                 us.disableAll();
                 us.setGlobalAddressBookDisabled(false); // by default this is enabled.
-                String[] modules = Strings.isEmpty(predefined_modules) ? new String[0] : predefined_modules.split(" *, *");
+                String[] modules = Strings.isEmpty(predefined_modules) ? new String[0] : Strings.splitByComma(predefined_modules);
                 for (String module : modules) {
                     module = module.trim();
                     Method meth = module_method_mapping.get(module);
@@ -396,8 +395,8 @@ public class AdminCache {
             throw new IllegalStateException("Absent service: " + ConfigurationService.class.getName());
         }
         try {
-            return ConfigurationServices.loadPropertiesFrom(service.getFileByName("ModuleAccessDefinitions.properties"));
-        } catch (IOException e) {
+            return service.getFile("ModuleAccessDefinitions.properties");
+        } catch (Exception e) {
             throw new OXGenericException("ModuleAccessDefinitions.properties file cannot be opened for reading!", e);
         }
     }
@@ -519,12 +518,8 @@ public class AdminCache {
      * @param ctx
      */
     public final void removeAdminCredentials(Context ctx) {
-        if (this.adminCredentialsCache.containsKey(ctx.getId())) {
-            this.adminCredentialsCache.remove(ctx.getId());
-        }
-        if (this.adminAuthMechCache.containsKey(ctx.getId())) {
-            this.adminAuthMechCache.remove(ctx.getId());
-        }
+        this.adminCredentialsCache.remove(ctx.getId());
+        this.adminAuthMechCache.remove(ctx.getId());
     }
 
     public boolean masterAuthenticationDisabled() {
@@ -741,7 +736,7 @@ public class AdminCache {
                     continue;
                 }
                 // Ok seems to be a line with user:pass entry
-                String[] user_pass_combination = line.split(":");
+                String[] user_pass_combination = Strings.splitByColon(line);
                 if (user_pass_combination.length < 3) {
                     throw new OXGenericException("Invalid mpasswd format.");
                 }
