@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -44,9 +44,12 @@ import java.util.Set;
 import java.util.concurrent.Callable;
 import java.util.concurrent.ConcurrentLinkedQueue;
 import java.util.concurrent.ExecutionException;
+import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicReference;
+import java.util.concurrent.locks.LockSupport;
 import org.apache.commons.io.FileUtils;
 import org.slf4j.Logger;
+import org.xml.sax.SAXParseException;
 import com.openexchange.admin.daemons.ClientAdminThread;
 import com.openexchange.admin.daemons.ClientAdminThreadExtended;
 import com.openexchange.admin.osgi.FilestoreLocationUpdaterRegistry;
@@ -60,6 +63,7 @@ import com.openexchange.admin.storage.utils.Filestore2UserUtil;
 import com.openexchange.admin.tools.AdminCache;
 import com.openexchange.database.Databases;
 import com.openexchange.databaseold.Database;
+import com.openexchange.exception.ExceptionUtils;
 import com.openexchange.exception.OXException;
 import com.openexchange.filestore.FileStorage;
 import com.openexchange.filestore.FileStorageCodes;
@@ -402,31 +406,15 @@ public abstract class FilestoreDataMover implements Callable<Void> {
         // One-by-one...
         try {
             final Map<String, String> prevFileName2newFileName = new HashMap<String, String>(files.size());
+            int maxRetries = 5;
 
             int i = 1;
             for (String file : files) {
-                InputStream is = null;
-                try {
-                    is = srcStorage.getFile(file);
-                    String newFile = dstStorage.saveNewFile(is);
-                    if (null != newFile) {
-                        prevFileName2newFileName.put(file, newFile);
-
-                        if ((i % LOG_THRESHOLD) == 0) {
-                            LOGGER.info("{} copied {} files of {} in total (with thread \"{}\")", moverName, Integer.valueOf(i), size, threadName);
-                        }
-                        i++;
-                    }
-                } catch (OXException e) {
-                    if (optionalFileNotFoundHandler.isPresent() && FileStorageCodes.FILE_NOT_FOUND.equals(e)) {
-                        optionalFileNotFoundHandler.get().handleFileNotFound(file, srcStorage);
-                    } else {
-                        // Re-throw
-                        throw e;
-                    }
-                } finally {
-                    Streams.close(is);
+                transferFileWithRetry(file, maxRetries, srcStorage, dstStorage, optionalFileNotFoundHandler, prevFileName2newFileName);
+                if ((i % LOG_THRESHOLD) == 0) {
+                    LOGGER.info("{} copied {} files of {} in total (with thread \"{}\")", moverName, Integer.valueOf(i), size, threadName);
                 }
+                i++;
             }
 
             LOGGER.info("{} copied {} files (with thread \"{}\").", moverName, size, threadName);
@@ -444,7 +432,8 @@ public abstract class FilestoreDataMover implements Callable<Void> {
                             try {
                                 dstStorage.deleteFile(copiedFile);
                             } catch (OXException e) {
-                                LOGGER.error("{} failed to revert file {} (with thread \"{}\")", moverName, copiedFile, threadName, e.getCause() == null ? e : e.getCause());
+                                Throwable cause = e.getCause() == null ? e : e.getCause();
+                                LOGGER.error("{} failed to revert file {} (with thread \"{}\")", moverName, copiedFile, threadName, cause);
                             }
                         }
                     }
@@ -457,6 +446,71 @@ public abstract class FilestoreDataMover implements Callable<Void> {
         }
     }
 
+    private static void transferFileWithRetry(String file, int maxRetries, FileStorage srcStorage, FileStorage dstStorage, Optional<FileNotFoundHandler> optionalFileNotFoundHandler, Map<String, String> prevFileName2newFileName) throws OXException, StorageException {
+        boolean retry = true;
+        int retryCount = 0;
+        do {
+            try {
+                transferFile(file, srcStorage, dstStorage, optionalFileNotFoundHandler, prevFileName2newFileName);
+                // Successfully transferred
+                retry = false;
+            } catch (Exception e) {
+                if (retryCount++ >= maxRetries || ExceptionUtils.isNoneOf(e, IOException.class, SAXParseException.class)) {
+                    LOGGER.info("Failed to write file {} to destination storage.", file, e);
+                    throw e;
+                }
+
+                // Retry using exponential back-off...
+                LOGGER.info("Could not write file {} to destination storage on {}. attempt due to a retry-able error (\"{}\"). Retrying...", file, I(retryCount), e.getMessage());
+                exponentialBackoffWait(retryCount, 1000L);
+            }
+        } while (retry);
+    }
+
+    /**
+     * Transfers specified file from source to destination storage.
+     *
+     * @param file The file
+     * @param srcStorage The source storage
+     * @param dstStorage The destination storage
+     * @param optionalFileNotFoundHandler The optional file-not-found handler
+     * @param prevFileName2newFileName The file name mapping
+     * @throws OXException If transfer fails
+     * @throws StorageException If file-not-found handler fails
+     */
+    private static void transferFile(String file, FileStorage srcStorage, FileStorage dstStorage, Optional<FileNotFoundHandler> optionalFileNotFoundHandler, Map<String, String> prevFileName2newFileName) throws OXException, StorageException {
+        InputStream is = srcStorage.getFile(file);
+        try {
+            String newFile = dstStorage.saveNewFile(is);
+            if (null != newFile) {
+                prevFileName2newFileName.put(file, newFile);
+            }
+        } catch (OXException e) {
+            if (optionalFileNotFoundHandler.isPresent() && FileStorageCodes.FILE_NOT_FOUND.equals(e)) {
+                optionalFileNotFoundHandler.get().handleFileNotFound(file, srcStorage);
+            } else {
+                // Re-throw
+                throw e;
+            }
+        } finally {
+            Streams.close(is);
+        }
+    }
+
+    /**
+     * Performs a wait according to exponential back-off strategy.
+     * <pre>
+     * (retry-count * base-millis) + random-millis
+     * </pre>
+     *
+     * @param retryCount The current number of retries
+     * @param baseMillis The base milliseconds
+     */
+    private static void exponentialBackoffWait(int retryCount, long baseMillis) {
+        long nanosToWait = TimeUnit.NANOSECONDS.convert((retryCount * baseMillis) + ((long) (Math.random() * baseMillis)), TimeUnit.MILLISECONDS);
+        LockSupport.parkNanos(nanosToWait);
+    }
+
     /**
      * Propagates new file locations throughout registered <code>FileLocationHandler</code> instances.
      *
